/******************************************************************************
    CallWave VoiceMail Widget

    Copyright (C) 2006 CallWave, Inc.  All Rights Reserved.

 ******************************************************************************/


/******************************************************************************
  VM_RegisterView c'tor

    HTML DOM Dependencies:
        WIDGET_registerViewFrame          - <div>
        WIDGET_registerViewStatusTextArea - <div>
        WIDGET_registerCellNumberTextArea - <input type="text">
        WIDGET_registerEmailTextArea      - <input type="text">
        WIDGET_registerPinTextArea        - <input type="password">

    Call backs:
        onRegisterAccountSuccess( responseMessage )

    Globals:
        VM_GetPreference( key )
        VM_SetPreference( key, value )
        EX_Log( message )
        VM_WIDGET_SOURCE
        VM_WIDGET_VERSION
        VM_WIDGET_OS_VERSION

 ******************************************************************************/
function VM_RegisterView( onRegisterAccountSuccess )
{
    this.m_onRegisterAccountSuccess = onRegisterAccountSuccess;

    // Account handler
    var self = this;
    this.m_accountHandler = new ACC_AccountHandler( VM_WIDGET_SOURCE,
                                                    VM_WIDGET_VERSION,
                                                    VM_WIDGET_OS_VERSION );
    this.m_accountHandler.m_onRegisterAccountSucceeded = function( responseMessage )
    {
        self.onRegisterAccountSucceeded( responseMessage );
    };
    this.m_accountHandler.m_onRegisterAccountFailed    = function( statusMessage )
    {
        self.onRegisterAccountFailed( statusMessage );
    };

    function AddEditFieldMethod( self, identifier )
    {
        eval( 'self.Set' + identifier + 'Data = function( message ) ' +
              '{'                                                     +
                  'document.getElementById( "WIDGET_register' + identifier + 'TextArea" ).value = message;' +
              '};'
            );

        eval( 'self.Get' + identifier + 'Data = function( ) '   +
              '{'                                               +
                  'return document.getElementById( "WIDGET_register' + identifier + 'TextArea" ).value;' +
              '};'
            );

        eval( 'self.Get' + identifier + 'Obj = function( ) '    +
              '{'                                               +
                  'return document.getElementById( "WIDGET_register' + identifier + 'TextArea" );' +
              '};'
            );
    }

    AddEditFieldMethod( this, 'CellNumber' );
    AddEditFieldMethod( this, 'Email' );
    AddEditFieldMethod( this, 'Pin' );
}
VM_RegisterView.prototype =
{
    VM_DEFAULT_REG_ERROR_MESSAGE : "Registration failed. Please try again later.",

    /**************************************************************************
      Accessor and modify methods
     **************************************************************************/

    SetStatusText : function ( message )
    {
        document.getElementById( 'WIDGET_registerViewStatusTextArea' ).innerHTML = message;
    },

    /**************************************************************************
      View repainting methods
     **************************************************************************/

    reset:function( )
    {
        document.getElementById( 'WIDGET_registerViewFrame' ).style.display = 'none';
    },

    refresh:function( )
    {
        document.getElementById( 'WIDGET_registerViewFrame' ).style.display = 'block';

        this.SetStatusText( '<span style="color: #000000">Please enter the following information to register:</span>' );

        var cellNumber = VM_GetPreference( PREF_KEY_CELL_NUMBER );

        if ( cellNumber )
        {
            this.SetCellNumberData( cellNumber );
        }

        this.GetCellNumberObj( ).focus( );
    },

    /**************************************************************************
      Register methods
     **************************************************************************/
    handleRegistrationSubmit:function( )
    {
        try
        {
            var cellNumber = UTILS_StripNonDigits( this.GetCellNumberData( ) );

            if ( cellNumber.length != 10 )
            {
                this.SetCellNumberData( "" );
                this.SetStatusText( "Please enter your 10-digit cell number." );
                return;
            }

            var PIN = UTILS_StripNonDigits( this.GetPinData( ) );

            if ( PIN.length != this.GetPinData( ).length )
            {
                this.SetPinData( "" );
                this.SetStatusText( "Please enter a 4-10 digit PIN (numeric characters only)." );
                return;
            }

            if ( PIN.length < 4 || PIN.length > 10  )
            {
                this.SetPinData( "" );
                this.SetStatusText( "Please enter a 4-10 digit PIN." );
                return;
            }

            VM_SetPreference( PREF_KEY_CELL_NUMBER, cellNumber );

            this.SetStatusText( "Connecting, please wait..." );

            this.m_accountHandler.registerAccount( cellNumber, PIN, this.GetEmailData( ) );

            // TODO: Disable Submit button
        }
        catch ( e )
        {
            this.SetStatusText( this.VM_DEFAULT_REG_ERROR_MESSAGE );

            EX_Log( "VM_RegisterView::handleRegistrationSubmit( ) : " + e.message );
        }
    },

    onRegisterAccountSucceeded:function( responseMessage )
    {
        try
        {
            switch ( responseMessage.m_status )
            {
            case MSG_ResponseStatus.SUCCESS:
                {
                    /*
                    TODO: what to do with responseMessage.m_successCase attribute
                    */

                    // Save persistent account attributes
                    VM_SetPreference( PREF_KEY_ACCOUNT, responseMessage.m_account );
                    VM_SetPreference( PREF_KEY_U_STRING, responseMessage.m_uString );

                    this.m_onRegisterAccountSuccess( );
                    break;
                }

            case MSG_ResponseStatus.UNEXPECTED_ERROR:
                {
                    this.SetStatusText( this.VM_DEFAULT_REG_ERROR_MESSAGE );
                    break;
                }

            case MSG_ResponseStatus.GENERAL_ERROR:
                {
                    this.SetStatusText( responseMessage.m_statusMsg );
                    break;
                }

            case MSG_ResponseStatus.RECOVERABLE_ERROR:
                {
                    this.SetStatusText( "Registration failed. Please try again." );
                    break;
                }

            case MSG_ResponseStatus.REGA_PIN_MISMATCH:
                {
                    VM_widgetViewController.setLoginRequired( );

                    var msg = responseMessage.m_statusMsg ? responseMessage.m_statusMsg : 'no message from CASE 10????';
                    VM_WidgetViewController.getLoginView( ).setLoginStatus( msg,
                                                                           VM_LOGIN_VIEW_ERROR_TEXT_COLOR );
                    break;

                }

            default:
                {
                    if ( responseMessage.m_statusMsg != null && responseMessage.m_statusMsg.length != 0 )
                    {
                        this.SetStatusText( responseMessage.m_statusMsg );
                    }
                    else
                    {
                        this.SetStatusText( this.VM_DEFAULT_REG_ERROR_MESSAGE );
                    }
                    break;
                }
            }
        }
        catch ( e )
        {
            this.SetStatusText( this.VM_DEFAULT_REG_ERROR_MESSAGE );
        }
    },

    onRegisterAccountFailed:function( statusMessage )
    {
        // TODO: Re-enable Submit button

        try
        {
            this.SetStatusText( this.VM_DEFAULT_REG_ERROR_MESSAGE );

            EX_Log( "VM_RegisterView::onRegisterAccountFailed( ) : " + statusMessage );
        }
        catch ( e )
        {
            EX_Log( "VM_RegisterView::onRegisterAccountFailed( ) : " + e );
        }
    }
}
